<?php
/**
 * phpaga
 *
 * Sample local config file.
 *
 * This is a sample config.local.php file. Copy it to config.local.php
 * and set the options according to your system's setup.
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @version $Id$
 *
 * Copyright (c) 2002, 2003 Florian Lanthaler <florian@phpaga.net>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *    * Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in
 *      the documentation and/or other materials provided with the
 *      distribution.
 *
 *    * Neither the name of Florian Lanthaler nor the names of his
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/* Database system; currently supported values are
 *	pgsql : PostgreSQL
 *	mysql : MySQL
 */
define('PHPAGA_DB_SYSTEM', 	'pgsql');

/* If you are using PostgreSQL with phpaga > 0.3a, and you are
 * accessing a database with an encoding different than UTF-8/Unicode,
 * make sure this is set to UTF-8 for PostgreSQL 8.x or to UNICODE for
 * PostgreSQL 7.x.
 *
 * If you use phpaga 0.3a or earlier and get an error similar to
 *
 * ERROR: invalid byte sequence for encoding "UTF8": 0xf4746520
 *
 * then uncomment the following setting and make sure the value
 * represents the correct encoding that phpaga is using (may depend on
 * the selected language/translation). The default setting LATIN1
 * should be fine for most installations.
 *
 * You can find more information about this at
 * http://www.postgresql.org/docs/8.1/interactive/multibyte.html
 *
 */
#define("PHPAGA_PGSQL_ENCODING", "UTF-8");   // PostgreSQL 8.x
#define("PHPAGA_PGSQL_ENCODING", "UNICODE"); // PostgreSQL 7.x

/* If you are using MySQL uncomment the following line and make sure
/* the definition points to the mysql executable. This is needed for
/* database upgrades, not for normal application activity. */

#define('PHPAGA_MYSQLBIN', '/usr/bin/mysql');

/* Name or IP address of the host the database server is running on.
/* Set this to the empty string '' if you want to connect via Unix domain
/* sockets */
define('PHPAGA_DB_HOST', 	'localhost');

/* Full absolute path to phpaga's base directory with trailing slash.
 * The path should be recognized and set automatically, but if you run
 * into any problems, comment it out, uncomment the next line below,
 * and set the path manually. */

define('PHPAGA_BASEPATH', preg_replace("/etc$/i", "", dirname(__FILE__)));
#define('PHPAGA_BASEPATH', '/home/webs/phpaga/');

/* Database name */
define('PHPAGA_DB_NAME', 	'phpaga');

/* Database username */
define('PHPAGA_DB_LOGIN', 	'yourdblogin');

/* Database password */
define('PHPAGA_DB_PASSWD', 	'yourdbpasswd');

/* Uncomment this if you want to disable uploads. This will regard all
/* uploads (documents, images) */

#define("PHPAGA_UPLOADS_DISABLED", true);

/* Uncomment this if you want to disable output compression */

#define("PHPAGA_COMPRESSOUT_DISABLED", true);

/* Uncomment this if you want detailed error messages regarding
 * database connection problems. This might expose critical
 * information like login and password to your database, therefore you
 * should use it only when you run into problems installing phpaga or
 * if you want to debug error messages you get from phpaga. */

#define("PHPAGA_ERR_VERBOSE", true);

/* Uncomment this if you want detailed error messages to be logged to
 * a database table. This can help track down errors but should not be
 * needed for daily use.
 */

#define("PHPAGA_ERRLOG", true);

/* If your php.ini does not have include_path set to include the
 * current directory (".") uncomment the following option.
 */

#ini_set("include_path", ini_get("include_path").":.:/usr/local/lib/php");

/* Uncomment the following setting if PHP runs out of memory some
 * distributions set PHP's default memory limit to 8 MB which may not
 * be enough.
 */

#ini_set("memory_limit", "16M");

/* If you want to disable the automatic creation of thumbnails for
 * supported file types set the following to false.
 */

#define("PHPAGA_FILES_PREVIEW", true);

/* If PHPAGA_FILES_PREVIEW is enabled you need to provide the full
 * path to 'convert', the conversion tool that is part of ImageMagick
 */

#define("PHPAGA_BIN_CONVERT", "/usr/bin/convert");

/* Full path to the 'dot' binary from the graphviz package. This is
 * only required if you enabled support for Graphviz in the sitewide
 * settings, and is used to create the relationship graphs.
 */

#define("PHPAGA_BIN_DOT", "/usr/bin/dot");

/* Full path to the/a temporary directory the web server process has
/* write access to. Usually this is not required, unless you use PHP's
/* safe mode. */

#define('PHPAGA_TMPDIR', '');

/* This setting is not required for official releases, only for those
 * who fetch the source code from the Subversion repository.
 *
 * Uncomment this if you have Smarty already installed on your system
 * and set the path accordingly. Otherwise leave it commented and
 * install Smarty as described in the installation documentation */

#define("SMARTY_DIR", "/usr/share/php/smarty/libs/");

/* This setting is not required for official releases, only for those
 * who fetch the source code from the Subversion repository.
 *
 * Uncomment this if you have smarty-gettext already installed on your
 * system and set the path accordingly.
 */

#define("SMARTYGETTEXT_DIR", "/usr/share/php/smarty/libs/plugins/");

?>
