<?php
/**
 * phpaga
 *
 * Person categories
 *
 * This is the person categories management interface.
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @version $Id$
 *
 * Copyright (c) 2002, Florian Lanthaler <florian@phpaga.net>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *    * Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in
 *      the documentation and/or other materials provided with the
 *      distribution.
 *
 *    * Neither the name of Florian Lanthaler nor the names of his
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

include_once('./config.php');
phpaga_user_pageperm(PHPAGA_PERM_MANAGE_SYSSETTINGS);

$rows = array();
$pecat_title = '';

phpaga_header(array('menuitem' => 'administration'));

if (isset ($REQUEST_DATA['action']) && strlen ($REQUEST_DATA['action']))
{

    switch ($REQUEST_DATA['action'])
    {

        case ACTION_ADD:

            if (isset($REQUEST_DATA['pecat_title']) && strlen($REQUEST_DATA['pecat_title'])) {

                $result = phpaga_persons_addPecat($REQUEST_DATA['pecat_title']);

                if (PhPagaError::isError($result)) {
                    $result->printMessage();
                    $pecat_title = $REQUEST_DATA['pecat_title'];
                }
                else
                    phpaga_message(_('Person category added'),
                                   sprintf(_('The person category %s has been inserted successfully.'), $REQUEST_DATA['pecat_title']));
            }
            break;

        case ACTION_DELETE:

            if (isset($REQUEST_DATA['id']) && strlen($REQUEST_DATA['id'])) {

                $result = phpaga_persons_deletePecat($REQUEST_DATA['id']);

                if (PhPagaError::isError($result)) {

                    /* if we could not delete the record because of
                     * dependencies then use a more descriptive error message */

                    if ($result->getCode() == PHPAGA_ERR_DEL_DEPENDENCIES)
                        phpaga_error(_('The person category cannot be deleted, as it is still used by some persons.'));
                    else
                        $result->printMessage();
                } else
                    phpaga_message(_('Person category deleted'),
                                   _('The person category has been successfully deleted.'));
            }

            break;

        default:
            break;
    }
}

$rows = phpaga_persons_getPecats();

if (PhPagaError::isError($rows))
    $rows->printMessage();

$tpl = new psmarty;

$tpl->assign('FORM_ACTION', basename($_SERVER['PHP_SELF']));
$tpl->assign('pecat_title', $pecat_title);
$tpl->assign('rows', $rows);

$tpl->display('pecats.tpl.html');

phpaga_footer ();

?>