<?php
/**
 * phpaga
 *
 * file preview
 *
 * Preview a file that has been associated to an internal object
 * (for example a project, a task, a company, a person, ...)
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @version $Id$
 *
 * Copyright (c) 2006, Florian Lanthaler <florian@phpaga.net>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *    * Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in
 *      the documentation and/or other materials provided with the
 *      distribution.
 *
 *    * Neither the name of Florian Lanthaler nor the names of his
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

include_once("./config.php");

ob_start();

$id = phpaga_fetch_REQUEST('id');

if (is_null($id)) {
    phpaga_error(_("Missing file ID."));
    exit;
}

if (!is_numeric($id)) {
    switch($id) {

    case 'LETTERHEAD_LOGO_FILE': 
        $file = array('file_original_name' => 'tn_'.PHPAGA_LETTERHEAD_LOGO_FILE);

        $dest_dir = PHPAGA_FILEPATH.'00/';
        $orig_file = $dest_dir.PHPAGA_LETTERHEAD_LOGO_FILE;
        $thumb_dir = $dest_dir;
        $thumb_file = $thumb_dir.'tn_'.PHPAGA_LETTERHEAD_LOGO_FILE;

        break;



    default:
        phpaga_error(_("Invalid file ID."));
        exit;
    }

} else {


    $file = phpaga_files_getInfo($REQUEST_DATA["id"]);

    if (PhPagaError::isError($file)) {
        $file->printMessage();
        exit;
    }

    switch ($file["file_rel_type"]) {
    case PHPAGA_RELTYPE_PROJECT:

        if (!phpaga_project_canview($file["file_rel_id"])) {
            phpaga_error(_("You are not allowed to access this file."));
            exit;
        }

    default:
        break;
    }

    $dest_dir = PHPAGA_FILEPATH.$file["file_rel_type"]."/".$file["file_rel_id"]."/";
    $orig_file = $dest_dir.$file["file_local_name"];
    $thumb_dir = $dest_dir.".thumbs/";
    $thumb_file = $thumb_dir.$file["file_local_name"].'.jpg';
}

if (isset($file["file_mimetype"]) && !in_array($file["file_mimetype"], $phpaga_preview_types))
    exit;

if (!is_dir($thumb_dir) && !mkdir($thumb_dir)) {
    phpaga_error(_("Unable to create thumbnail directory"));
    exit;
}

if (file_exists($thumb_file) && (filemtime($thumb_file) < filemtime($orig_file)))
    unlink($thumb_file);

if (!file_exists($thumb_file)) {

    if (isset($file["file_mimetype"]) && in_array($file["file_mimetype"], $phpaga_preview_types_firstpage))
        $orig_file .="[0]"; // first page only

    $command = sprintf("%s -size 100x100 %s -resize 100x100 %s",
        PHPAGA_BIN_CONVERT,
        escapeshellcmd($orig_file),
        escapeshellcmd($thumb_file));
    $ex = `$command`;
}

header("Expires: Thu, 26 Jul 2007 11:00:00 GMT");
header("Last-Modified: ".gmdate("D, d M Y H:i:s")." GMT");
header("Cache-Control: no-cache, must-revalidate");
header("Pragma: no-cache");
header("Cache-Control: post-check=0, pre-check=0", false);
//header("Content-Disposition: inline");
header("Content-Disposition: inline; filename=tn_".$file["file_original_name"]);
//header("Content-length: ".filesize($thumb_file));
header("Content-type: image/jpg");

if ($f = fopen($thumb_file, "rb"))

    while(!feof($f)) {
        $buffer = fread($f, 4096);
        print $buffer;
    }

ob_end_flush();

?>
