<?php
/**
 * phpaga
 *
 * product
 *
 * View product information
 *
 * @author Florian Lanthaler <florian@phpaga.net>
 * @version $Id$
 *
 * Copyright (c) 2002, Florian Lanthaler <florian@phpaga.net>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *    * Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in
 *      the documentation and/or other materials provided with the
 *      distribution.
 *
 *    * Neither the name of Florian Lanthaler nor the names of his
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

include_once('./config.php');

$error = array();
$action = ACTION_NONE;

if (isset($REQUEST_DATA['action']) && is_numeric($REQUEST_DATA['action']))
    $action = $REQUEST_DATA['action'];

if (isset($REQUEST_DATA['id']) && is_numeric($REQUEST_DATA['id']))
    $prod_id = $REQUEST_DATA['id'];

switch($action) {

    case ACTION_REMOVE:

        if (!phpaga_user_hasperm(PHPAGA_PERM_MANAGE_SYSSETTINGS)) {
            phpaga_header(array('menuitem' => 'core'));
            phpaga_message(_('No access'), _('You are not allowed to delete this record.'));
            phpaga_footer();
            exit;
        }

        $result = phpaga_products_delete($prod_id);
        if (!PhPagaError::isError($result)) {
            header('Location: products.php?d=1');
            exit;
        } else if ($result->getCode() == PHPAGA_ERR_DEL_DEPENDENCIES)
            $error[] = (_('The product cannot be deleted, as it is still used by other records.'));
        else
            $error[] = $result->getCode();
        break;

    default:
        break;
}

phpaga_header(array('menuitem' => 'core'));

$prodInfo = phpaga_products_getInfo($prod_id);

if (PhPagaError::isError($prodInfo))
    $prodInfo->printMessage();
else {

    if (count($error) > 0)
        phpaga_error($error);

    $config = phpaga_config_get();

    $tpl = new psmarty;
    $tpl->assign('product', $prodInfo);
    $tpl->assign('perm_products', phpaga_user_hasperm(PHPAGA_PERM_MANAGE_SYSSETTINGS));
    $tpl->assign('config', $config);
    $tpl->display('product.tpl.html');
}

phpaga_footer();

?>
