/*
 * phpaga
 * upgrade9.pgsql
 * Michael Kimmick <support@nichewares.com>
 * Nichewares & Consulting, LLC
 * 2009-03-05
 *
 * Multiple updates to support new features: payments, latefees, invoice and payment
 * notes, bar chart highlighting, display control of formatting characters
 *
 *
 */



-- Core db update generated by apgdiff-1.3 

CREATE SEQUENCE latefees_fee_id_seq
	INCREMENT BY 1
	NO MAXVALUE
	NO MINVALUE
	CACHE 1
	CYCLE;

CREATE SEQUENCE payments_pmt_id_seq
	INCREMENT BY 1
	NO MAXVALUE
	NO MINVALUE
	CACHE 1
	CYCLE;

CREATE TABLE latefees (
	fee_id bigint DEFAULT nextval(('latefees_fee_id_seq'::text)::regclass) NOT NULL,
	bill_id bigint NOT NULL,
	fee_amt numeric(12,2) NOT NULL,
	fee_date date DEFAULT ('now'::text)::date NOT NULL
);

CREATE TABLE payments (
	pmt_id bigint DEFAULT nextval(('payments_pmt_id_seq'::text)::regclass) NOT NULL,
	bill_id bigint NOT NULL,
	pmt_amt numeric(12,2) NOT NULL,
	pmt_date date NOT NULL,
	pmt_note text
);

ALTER TABLE bills
	ADD COLUMN bill_note text DEFAULT ''::text;

ALTER TABLE latefees
	ADD CONSTRAINT latefees_pkey PRIMARY KEY (fee_id);

ALTER TABLE payments
	ADD CONSTRAINT payments_pkey PRIMARY KEY (pmt_id);

ALTER TABLE latefees
	ADD CONSTRAINT bills_bill_id FOREIGN KEY (bill_id) REFERENCES bills(bill_id);

ALTER TABLE payments
	ADD CONSTRAINT bills_bill_id FOREIGN KEY (bill_id) REFERENCES bills(bill_id);

CREATE INDEX billid_latefees_index ON latefees USING btree (bill_id);

CREATE INDEX feeid_latefees_index ON latefees USING btree (fee_id);

CREATE INDEX billid_payments_index ON payments USING btree (bill_id);

CREATE INDEX fki_bills_bill_id ON payments USING btree (bill_id);

CREATE INDEX pmtid_payments_index ON payments USING btree (pmt_id);

CREATE VIEW v_bills AS
	SELECT DISTINCT bills.bill_id, bills.bill_number, bills.bill_date, bills.cpn_id, bills.bill_sent, bills.bill_paydate, bills.bill_startsum, bills.bill_endsum, bills.bmt_id, bills.curr_id, bills.bill_footer, bills.bill_payterm, bills.bill_date_due, bills.pe_id_recipient, bills.rbill_id, bills.bill_note, bills.bill_additional_line, (SELECT sum(payments.pmt_amt) AS sum FROM payments WHERE (payments.bill_id = bills.bill_id)) AS pamt, (bills.bill_endsum - (SELECT sum(payments.pmt_amt) AS pmts FROM payments WHERE (payments.bill_id = bills.bill_id))) AS missing_pmt FROM ((bills LEFT JOIN payments ON ((payments.bill_id = bills.bill_id))) LEFT JOIN currencies ON ((currencies.curr_id = bills.curr_id))) ORDER BY bills.bill_id, bills.bill_date, bills.bill_paydate, bills.curr_id, (bills.bill_endsum - (SELECT sum(payments.pmt_amt) AS pmts FROM payments WHERE (payments.bill_id = bills.bill_id))), bills.bill_number, bills.cpn_id, bills.bill_sent, bills.bill_startsum, bills.bill_endsum, bills.bmt_id, bills.bill_footer, bills.bill_payterm, bills.bill_date_due, bills.pe_id_recipient, bills.rbill_id, bills.bill_note, bills.bill_additional_line, (SELECT sum(payments.pmt_amt) AS sum FROM payments WHERE (payments.bill_id = bills.bill_id));

-- End Core DB Upgrade 


-- Add default values to config table
INSERT INTO config (cfg_key, cfg_value) VALUES ('PHPAGA_LATE_FEE', '1.5');
INSERT INTO config (cfg_key, cfg_value) VALUES ('SHOW_SET_PAYMENT_DATE', 'false');
INSERT INTO config (cfg_key, cfg_value) VALUES ('HIGHLIGHT_BARCHART', 'false');
INSERT INTO config (cfg_key, cfg_value) VALUES ('MONETARY_SYMBOL', '');
INSERT INTO config (cfg_key, cfg_value) VALUES ('SHOW_CURRENCY', 'true');


-- Migrate paid bills from bills table to new payments table

INSERT INTO payments (bill_id, pmt_amt, pmt_date, pmt_note)
SELECT bill_id, bill_endsum, bill_paydate, 'migrated payment' FROM bills WHERE bill_paydate IS NOT
NULL;

